from setuptools import setup

setup(
	name = "turingmachine_ezrashare31",
	long_description = open("README.md").read(),
	long_description_content_type = "text/markdown",
	version = "1.0.0",
	license = "MIT",
	description = "a simple turing machine with an API for some awkward reason."
)
